@@ -9,11 +9,11 @@ Task::Devel::Cover::Recommended - Install Devel::Cover and its recommended depen
 
 =head1 VERSION
 
-Version v1.80.0
+Version v1.200.0
 
 =cut
 
-our $VERSION = 'v1.80.0';
+our $VERSION = 'v1.200.0';
 
 =head1 SYNOPSIS
 
@@ -23,7 +23,7 @@ our $VERSION = 'v1.80.0';
 
 =head1 DESCRIPTION
 
-This task module lets you easily install L<Devel::Cover> 1.08 and all its recommended dependencies.
+This task module lets you easily install L<Devel::Cover> 1.20 and all its recommended dependencies.
 
 =head1 DEPENDENCIES
 
@@ -49,10 +49,6 @@ L<ExtUtils::MakeMaker>
 
 L<Test::More>
 
-=item *
-
-L<Test::Warn>
-
 =back
 
 =head2 Run-time dependencies
@@ -61,7 +57,7 @@ L<Test::Warn>
 
 =item *
 
-L<Devel::Cover> 1.08
+L<Devel::Cover> 1.20
 
 =item *
 
@@ -73,6 +69,14 @@ L<Browser::Open>
 
 =item *
 
+L<Capture::Tiny>
+
+=item *
+
+L<Class::XSAccessor>
+
+=item *
+
 L<Digest::MD5>
 
 =item *
@@ -81,6 +85,10 @@ L<JSON::PP>
 
 =item *
 
+L<Moo>
+
+=item *
+
 L<PPI::HTML> 1.07
 
 Devel::Cover lets you optionally pick between L<PPI::HTML> and L<Perl::Tidy>, but it will only use the former if both are installed.
@@ -105,6 +113,10 @@ L<Storable>
 
 L<Template> 2.00
 
+=item *
+
+L<namespace::clean>
+
 =back
 
 =head1 CAVEATS
@@ -131,7 +143,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012,2013 Vincent Pit, all rights reserved.
+Copyright 2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
